pub fn new_in_memory_queue() -> (InMemoryQueueWriter, InMemoryQueueReader)Expand description
Creates a new in-memory event queue pair with the default capacity and default max event size.
pub fn new_in_memory_queue() -> (InMemoryQueueWriter, InMemoryQueueReader)Creates a new in-memory event queue pair with the default capacity and default max event size.