pub struct InMemoryQueueWriter { /* private fields */ }Expand description
In-memory EventQueueWriter backed by an mpsc channel sender.
Enforces a maximum serialized event size to prevent OOM from oversized events written by executors, and a write timeout to prevent blocking indefinitely on slow clients (PR-1).